//	ListFileView.h - FileView displaying files in Windows Explorer's list
//					 style.
//	--------------------------------------------------------------------------
//	This file is part of 'Phil', a very simple file manager/browser for the
//	JUCE library.
//	Copyright (C) 2005-2006  Niall Moody
//	
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//	
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//	
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//	
//	--------------------------------------------------------------------------

#ifndef LISTFILEVIEW_H_
#define LISTFILEVIEW_H_

#include "FileView.h"

///	FileView displaying files in Windows Explorer's list style.
class ListFileView : public FileView,
					 public DragAndDropContainer,
					 public DragAndDropTarget
{
  public:
	///	Constructor.
	ListFileView(Phil *parent);
	///	Destructor.
	~ListFileView();

	///	Draws the files.
	void paint(Graphics& g);
	///	To determine when a file/directory has been selected/highlighted.
	void mouseDown(const MouseEvent &e);
	///	To determine when multiple files/directories have been selected.
	void mouseDrag(const MouseEvent &e);
	///	Used to change directories etc.
	void mouseDoubleClick(const MouseEvent &e);
	///	So we can implement drag and drop to move files.
	bool isInterestedInDragSource(const String &sourceDescription);
	///	So we can implement drag and drop to move files.
	void itemDropped(const String &sourceDescription,
					 Component *sourceComponent,
					 int x,
					 int y);
	///	So we can highlight folders when a file is dragged over them.
	void itemDragMove(const String &sourceDescription,
					  Component *sourceComponent,
					  int x,
					  int y);
	///	Called when the user presses a key.
	/*!
  		We use this to implement alphabetical navigation - i.e. you press 'f',
		and the next file beginning with f (or F) is highlighted.

		I'd have preferred it to be in Phil, but I couldn't think of a sensible
		way of doing that...
	 */
	void keyPressed(const KeyPress &key);

	///	Called by Phil to resize the view accordingly.
	void updateSize(int width, int height, long numChildren);
	///	Called by Phil to determine how to scroll the enclosing Viewport.
	const Rectangle& getSelectedBounds() const;

	juce_UseDebuggingNewOperator
  private:
	///	Helper method used to determine if the user clicked on a file etc.
	long getClickedOnIndex(int x, int y);

	///	The number of items we display in a single column.
	int numColumnItems;
	///	The width of the columns.
	/*!
		TODO: Set this automatically according to the size of the text drawn.
	 */
	int columnWidth;

	///	This is used when the user is dragging the mouse.
	/*!
		We use it to work out whether we should call
		Phil::anotherFileSelected() again, or if we're still over the previous
		file.
	 */
	long previousFile;
};

#endif
