//	XYPad.cpp - Simple x-y pad widget.
//	----------------------------------------------------------------------------
//	This file is part of Mouse To OSC, a simple OSC-outputting program.
//	Copyright (c) 2006 Niall Moody.
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//	----------------------------------------------------------------------------

#include <juce.h>
#include "XYPad.h"

//------------------------------------------------------------------------------
XYPad::XYPad():
Component(),
ChangeBroadcaster(),
xPos(0),
yPos(0),
draggingPad(false),
highlightPad(false)
{
	setBufferedToImage(true);
	startTimer(50);
}

//------------------------------------------------------------------------------
XYPad::~XYPad()
{
	
}

//------------------------------------------------------------------------------
void XYPad::paint(Graphics& g)
{
	//Draw background.
	g.setColour(Colours::white);
	g.fillRoundedRectangle(0, 0, getWidth(), getHeight(), 5);

	//Draw pad control.
	g.setColour(Colours::lightblue);
	g.fillEllipse(xPos, (getHeight()-yPos-10), 10, 10);
	if(highlightPad)
		g.setColour(Colours::black);
	else
		g.setColour(Colours::black.withAlpha(0.5f));
	g.drawEllipse(xPos, (getHeight()-yPos-10), 10, 10, 2);
}

//------------------------------------------------------------------------------
void XYPad::mouseDown(const MouseEvent& e)
{
	if((e.x > xPos) && (e.x < (xPos+10)))
	{
		if((e.y > (getHeight()-yPos-10)) && (e.y < (getHeight()-yPos+10)))
			draggingPad = true;
	}
}

//------------------------------------------------------------------------------
void XYPad::mouseMove(const MouseEvent& e)
{
	if((e.x > xPos) && (e.x < (xPos+10)))
	{
		if((e.y > (getHeight()-yPos-10)) && (e.y < (getHeight()-yPos+10)))
		{
			highlightPad = true;
			repaint();
		}
		else if(highlightPad)
		{
			highlightPad = false;
			repaint();
		}
	}
	else if(highlightPad)
	{
		highlightPad = false;
		repaint();
	}
}

//------------------------------------------------------------------------------
void XYPad::mouseDrag(const MouseEvent& e)
{
	if(draggingPad)
	{
		if((e.x-5) > (getWidth()-10))
			xPos = getWidth()-10;
		else if(e.x < 5)
			xPos = 0;
		else
			xPos = e.x-5;
		if((e.y-5) > (getHeight()-10))
			yPos = 0;
		else if(e.y < 5)
			yPos = getHeight()-10;
		else
			yPos = (getHeight()-10) - (e.y-5);

		repaint();
		sendChangeMessage(this);
	}
}

//------------------------------------------------------------------------------
void XYPad::mouseUp(const MouseEvent& e)
{
	if(draggingPad)
		draggingPad = false;
}

//------------------------------------------------------------------------------
void XYPad::timerCallback()
{
	repaint();
}

//------------------------------------------------------------------------------
void XYPad::setXVal(float val)
{
	xPos = (int)(val * (getWidth()-10));
	//repaint();
}

//------------------------------------------------------------------------------
void XYPad::setYVal(float val)
{
	yPos = (int)(val * (getHeight()-10));
	//repaint();
}

//------------------------------------------------------------------------------
void XYPad::setXYVal(float xVal, float yVal)
{
	xPos = (int)(xVal * (getWidth()-10));
	yPos = (int)(yVal * (getHeight()-10));
	//repaint();
}
